# Copyright 2017-2020 Mateusz Klos
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#
"""

Overview
========

`peltak_appengine` implements the ``peltak appengine`` group of commands
designed to streamline work with Google AppEngine projects.

Configuration
=============

.. code-block:: yaml

    appengine:
        deployables: '.'
        projects:
            branch: '*'
            app_id: 'my-appspot-project-id'

"""
from .cli import appengine_cli  # noqa: F401
